@@ -1,6 +1,8 @@
 """
 table2ascii - Library for converting 2D Python lists to fancy ASCII/Unicode tables
 """
+import sys
+from typing import TYPE_CHECKING
 
 from .alignment import Alignment
 from .merge import Merge
@@ -8,7 +10,12 @@ from .preset_style import PresetStyle
 from .table_style import TableStyle
 from .table_to_ascii import table2ascii
 
-__version__ = "1.0.4"
+if TYPE_CHECKING or sys.version_info >= (3, 8):
+    from importlib import metadata
+else:
+    import importlib_metadata as metadata
+
+__version__ = metadata.version(__name__)
 
 __all__ = [
     "Alignment",
