@@ -67,15 +67,21 @@ class TableToAscii:
         if not header and not body and not footer:
             raise NoHeaderBodyOrFooterError()
 
+        self.__alignments = self.__determine_alignments(
+            options.alignments, default=Alignment.CENTER
+        )
+        self.__number_alignments = self.__determine_alignments(
+            options.number_alignments, default=self.__alignments
+        )
+
+        # keep track of the number widths and positions of the decimal points for decimal alignment
+        decimal_widths, decimal_positions = self.__calculate_decimal_widths_and_positions()
+        self.__decimal_widths: list[int] = decimal_widths
+        self.__decimal_positions: list[int] = decimal_positions
+
         # calculate or use given column widths
         self.__column_widths = self.__calculate_column_widths(options.column_widths)
 
-        self.__alignments = options.alignments or [Alignment.CENTER] * self.__columns
-
-        # check if alignments specified have a different number of columns
-        if options.alignments and len(options.alignments) != self.__columns:
-            raise AlignmentCountMismatchError(options.alignments, self.__columns)
-
         # check if the cell padding is valid
         if self.__cell_padding < 0:
             raise InvalidCellPaddingError(self.__cell_padding)
@@ -97,6 +103,33 @@ class TableToAscii:
             return len(self.__body[0])
         return 0
 
+    def __determine_alignments(
+        self,
+        user_alignments: Sequence[Alignment] | Alignment | None,
+        *,
+        default: Sequence[Alignment] | Alignment,
+    ) -> list[Alignment]:
+        """Determine the alignments for each column based on the user provided alignments option.
+
+        Args:
+            user_alignments: The alignments specified by the user
+            default: The default alignments to use if user_alignments is None
+
+        Returns:
+            The alignments for each column in the table
+        """
+        alignments = user_alignments if user_alignments is not None else default
+
+        # if alignments is a single Alignment, convert it to a list of that Alignment
+        if isinstance(alignments, Alignment):
+            alignments = [alignments] * self.__columns
+
+        # check if alignments specified have a different number of columns
+        if len(alignments) != self.__columns:
+            raise AlignmentCountMismatchError(alignments, self.__columns)
+
+        return list(alignments)
+
     def __auto_column_widths(self) -> list[int]:
         """Get the minimum number of characters needed for the values in each column in the table
         with 1 space of padding on each side.
@@ -125,10 +158,46 @@ class TableToAscii:
             header_size = get_column_width(self.__header, i) if self.__header else 0
             body_size = max(get_column_width(row, i) for row in self.__body) if self.__body else 0
             footer_size = get_column_width(self.__footer, i) if self.__footer else 0
+            min_text_width = max(header_size, body_size, footer_size, self.__decimal_widths[i])
             # get the max and add 2 for padding each side with a space depending on cell padding
-            column_widths.append(max(header_size, body_size, footer_size) + self.__cell_padding * 2)
+            column_widths.append(min_text_width + self.__cell_padding * 2)
         return column_widths
 
+    def __calculate_decimal_widths_and_positions(self) -> tuple[list[int], list[int]]:
+        """Calculate the positions of the decimal points for decimal alignment.
+
+        Returns:
+            A tuple of the widths of the decimal numbers in each column
+            and the positions of the decimal points in each column
+        """
+        decimal_widths: list[int] = [0] * self.__columns
+        decimal_positions: list[int] = [0] * self.__columns
+        for i in range(self.__columns):
+            # skip if the column is not decimal aligned
+            if self.__number_alignments[i] != Alignment.DECIMAL:
+                continue
+            # list all values in the i-th column of header, body, and footer
+            values = [str(self.__header[i])] if self.__header else []
+            values += [str(row[i]) for row in self.__body] if self.__body else []
+            values += [str(self.__footer[i])] if self.__footer else []
+            # filter out values that are not numbers and split at the decimal point
+            split_values = [
+                self.__split_decimal(value) for value in values if self.__is_number(value)
+            ]
+            # skip if there are no decimal values
+            if len(split_values) == 0:
+                continue
+            # get the max number of digits before and after the decimal point
+            max_before_decimal = max(self.__str_width(parts[0]) for parts in split_values)
+            max_after_decimal = max(self.__str_width(parts[1]) for parts in split_values)
+            # add 1 for the decimal point if there are any decimal point values
+            has_decimal = any(self.__is_number(value) and "." in value for value in values)
+            # store the total width of the decimal numbers in the column
+            decimal_widths[i] = max_before_decimal + max_after_decimal + int(has_decimal)
+            # store the max digits before the decimal point for decimal alignment
+            decimal_positions[i] = max_before_decimal
+        return decimal_widths, decimal_positions
+
     def __calculate_column_widths(
         self, user_column_widths: Sequence[int | None] | None
     ) -> list[int]:
@@ -169,30 +238,47 @@ class TableToAscii:
         if self.__footer and self.__footer[0] == Merge.LEFT:
             self.__footer[0] = ""
 
-    def __pad(self, cell_value: SupportsStr, width: int, alignment: Alignment) -> str:
+    def __pad(self, cell_value: SupportsStr, width: int, col_index: int) -> str:
         """Pad a string of text to a given width with specified alignment
 
         Args:
             cell_value: The text in the cell to pad
             width: The width in characters to pad to
-            alignment: The alignment to use
+            col_index: The index of the column
 
         Returns:
             The padded text
         """
+        alignment = self.__alignments[col_index]
         text = str(cell_value)
+        # set alignment for numeric values
+        if self.__is_number(text):
+            # if the number alignment is decimal, pad such that the decimal point
+            # is aligned to the column's decimal position and use the default alignment
+            if self.__number_alignments[col_index] == Alignment.DECIMAL:
+                decimal_position = self.__decimal_positions[col_index]
+                decimal_max_width = self.__decimal_widths[col_index]
+                text_before_decimal = self.__split_decimal(text)[0]
+                before = " " * (decimal_position - self.__str_width(text_before_decimal))
+                after = " " * (decimal_max_width - self.__str_width(text) - len(before))
+                text = f"{before}{text}{after}"
+            # otherwise use the number alignment as the alignment for the cell
+            else:
+                alignment = self.__number_alignments[col_index]
+        # add minimum cell padding around the text
         padding = " " * self.__cell_padding
         padded_text = f"{padding}{text}{padding}"
         text_width = self.__str_width(padded_text)
+        # pad the text based on the alignment
         if alignment == Alignment.LEFT:
             # pad with spaces on the end
             return padded_text + (" " * (width - text_width))
-        if alignment == Alignment.CENTER:
+        elif alignment in (Alignment.CENTER, Alignment.DECIMAL):
             # pad with spaces, half on each side
             before = " " * floor((width - text_width) / 2)
             after = " " * ceil((width - text_width) / 2)
             return before + padded_text + after
-        if alignment == Alignment.RIGHT:
+        elif alignment == Alignment.RIGHT:
             # pad with spaces at the beginning
             return (" " * (width - text_width)) + padded_text
         raise InvalidAlignmentError(alignment)
@@ -403,7 +489,7 @@ class TableToAscii:
         return self.__pad(
             cell_value=col_content,
             width=pad_width,
-            alignment=self.__alignments[col_index],
+            col_index=col_index,
         )
 
     def __top_edge_to_ascii(self) -> str:
@@ -530,6 +616,19 @@ class TableToAscii:
         # if use_wcwidth is False or wcswidth fails, fall back to len
         return width if width >= 0 else len(text)
 
+    @staticmethod
+    def __is_number(text: str) -> bool:
+        """Returns True if the string is a number, with or without a decimal point"""
+        return text.replace(".", "", 1).isdecimal()
+
+    @staticmethod
+    def __split_decimal(text: str) -> tuple[str, str]:
+        """Splits a string into a tuple of the integer and decimal parts"""
+        if "." in text:
+            before, after = text.split(".", 1)
+            return before, after
+        return text, ""
+
     def to_ascii(self) -> str:
         """Generates a formatted ASCII table
 
@@ -569,16 +668,14 @@ def table2ascii(
     first_col_heading: bool = False,
     last_col_heading: bool = False,
     column_widths: Sequence[int | None] | None = None,
-    alignments: Sequence[Alignment] | None = None,
+    alignments: Sequence[Alignment] | Alignment | None = None,
+    number_alignments: Sequence[Alignment] | Alignment | None = None,
     cell_padding: int = 1,
     style: TableStyle = PresetStyle.double_thin_compact,
     use_wcwidth: bool = True,
 ) -> str:
     """Convert a 2D Python table to ASCII text
 
-    .. versionchanged:: 1.0.0
-        Added the ``use_wcwidth`` parameter defaulting to :py:obj:`True`.
-
     Args:
         header: List of column values in the table's header row. All values should be :class:`str`
             or support :class:`str` conversion. If not specified, the table will not have a header row.
@@ -595,8 +692,21 @@ def table2ascii(
             is passed instead of a :class:`~collections.abc.Sequence`, all columns will be automatically
             sized. Defaults to :py:obj:`None`.
         alignments: List of alignments for each column
-            (ex. ``[Alignment.LEFT, Alignment.CENTER, Alignment.RIGHT]``). If not specified or set to
-            :py:obj:`None`, all columns will be center-aligned. Defaults to :py:obj:`None`.
+            (ex. ``[Alignment.LEFT, Alignment.CENTER, Alignment.RIGHT, Alignment.DECIMAL]``)
+            or a single alignment to apply to all columns (ex. ``Alignment.LEFT``).
+            If not specified or set to :py:obj:`None`, all columns will be center-aligned.
+            Defaults to :py:obj:`None`.
+
+            .. versionchanged:: 1.1.0
+                ``alignments`` can now also be specified as a single :class:`Alignment` value to apply to all columns.
+        number_alignments: List of alignments for numeric values in each column or a single alignment
+            to apply to all columns. This argument can be used to override the alignment of numbers and
+            is ignored for non-numeric values. Numeric values include integers, floats, and strings containing only
+            :meth:`decimal <str.isdecimal>` characters and at most one decimal point.
+            If not specified or set to :py:obj:`None`, numbers will be aligned based on the ``alignments`` argument.
+            Defaults to :py:obj:`None`.
+
+            .. versionadded:: 1.1.0
         cell_padding: The minimum number of spaces to add between the cell content and the column
             separator. If set to ``0``, the cell content will be flush against the column separator.
             Defaults to ``1``.
@@ -608,6 +718,8 @@ def table2ascii(
             zero-width space, etc.), whereas :func:`len` determines the width solely based on the number of
             characters in the string. Defaults to :py:obj:`True`.
 
+            .. versionadded:: 1.0.0
+
     Returns:
         The generated ASCII table
     """
@@ -620,6 +732,7 @@ def table2ascii(
             last_col_heading=last_col_heading,
             column_widths=column_widths,
             alignments=alignments,
+            number_alignments=number_alignments,
             cell_padding=cell_padding,
             style=style,
             use_wcwidth=use_wcwidth,
